@@ -1,13 +1,10 @@
-import codecs
 import os
-from inspect import getsourcefile
 
 from spacy.language import Language
 
-from ..constants import B_DECR, B_INCR
-from ..utils import lexicons, components, read_lexicon
 from ..component import Asent
-
+from ..constants import B_DECR, B_INCR
+from ..utils import components, lexicons, read_lexicon
 from .emoji import LEXICON as E_LEXICON
 
 apath = os.path.dirname(os.path.abspath(__file__))
@@ -172,9 +169,8 @@ lexicons.register("intensifiers_en_v1", func=INTENSIFIERS)
 
 @Language.factory("asent_en_v1", default_config={"force": True})
 def create_en_sentiment_component(nlp: Language, name: str, force: bool) -> Language:
-    """
-    Allows the English sentiment to be added to a spaCy pipe using nlp.add_pipe("asent_en_v1").
-    """
+    """Allows the English sentiment to be added to a spaCy pipe using
+    nlp.add_pipe("asent_en_v1")."""
     LEXICON.update(E_LEXICON)
 
     return Asent(
