@@ -1,4 +1,5 @@
 from typing import Callable, Dict
+
 import catalogue
 
 lexicons = catalogue.create("asent", "lexicon", entry_points=True)
@@ -6,7 +7,7 @@ components = catalogue.create("asent", "components", entry_points=True)
 
 
 def register_lexicon(name: str, lexicon: Dict[str, float]) -> None:
-    """Registers a lexicon in asent.lexicons
+    """Registers a lexicon in asent.lexicons.
 
     Args:
         name (str): The name of the lexicon
@@ -21,7 +22,7 @@ def register_lexicon(name: str, lexicon: Dict[str, float]) -> None:
 
 
 def register_component(name: str, func: Callable) -> None:
-    """Registers a component in asent.components
+    """Registers a component in asent.components.
 
     Args:
         name (str): The name of the lexicon
